@@ -1,6 +1,4 @@
-<?php
-$heroType = get_sub_field('hero_type');
-?>
+<?php $heroType = get_sub_field('hero_type'); ?>
 
 <div class="custom-flexible-section hero-section <?= 'type-' . $heroType; ?>">
     <?php if($heroType == 'image') {
@@ -9,27 +7,36 @@ $heroType = get_sub_field('hero_type');
             <img src="<?= $image['url']; ?>">
         </div>
     <?php } else {
-        $previewVideo = get_sub_field('hero_video_preview'); ?>
+        $previewVideo = get_sub_field('hero_video_preview');
+        $mainVideo = get_sub_field('hero_video_full');
+        $opaqueLogo = get_template_directory_uri() . '/dist/images/opaque-logo.png';
+        ?>
         <div class="video-holder">
-
-            <video autoplay muted>
+            <video autoplay muted loop>
                 <source src="<?= $previewVideo['url']; ?>" type="video/mp4">
             </video>
-
             <div class="video-overlay">
                 <div class="video-image"><img src="<?= get_template_directory_uri() . '/dist/images/video-overlay.png'; ?>" alt="#LoveDougalston"></div>
                 <div class="cta">
                     <a href="" id="trigger-video">Watch Video</a>
                 </div>
             </div>
-
             <div class="scroll-to">
                 <div class="bar"></div>
                 <div class="show-text">Learn More</div>
             </div>
-
         </div>
-
-
+        <div class="main-video-block" style="background-image:url('<?= get_template_directory_uri() . '/dist/images/bg-pattern.png'; ?>')">
+            <div class="back"><i class="far fa-arrow-left"></i> Back</div>
+            <img src="<?= $opaqueLogo; ?>">
+            <div class="container">
+                <div class="inner-video-holder">
+                    <video id="featured-video" controls>
+                        <source src="<?= $mainVideo['url']; ?>" type="video/mp4">
+                    </video>
+                </div>
+            </div>
+        </div>
     <?php } ?>
 </div>
+
